@@ -37,6 +37,11 @@ void ContigGraph::InitializeTable()
     const double err = 0.01;
     double p_err = err/3 * pow(1-err, double(kmer_size_-1));
 
+    p_table.resize(10);
+    for (unsigned i = 0; i < 10; ++i) {
+        p_table.resize(1000);
+    }
+
     for (int m = 1; m < 10; ++m)
     {
         for (int x = 1; x < 1000; ++x)
@@ -219,7 +224,6 @@ void ContigGraph::MergeSimilarPath()
 
             if (current.out_edges().size() > 1)
             {
-                ContigGraphVertexAdaptor end(NULL);
                 deque<ContigGraphVertexAdaptor> neighbors;
                 GetNeighbors(current, neighbors);
                 sort(neighbors.begin(), neighbors.end(), CompareContigCoverage);
@@ -247,7 +251,6 @@ void ContigGraph::MergeSimilarPath()
     }
     Refresh();
     MergeSimplePaths();
-
 }
 
 int64_t ContigGraph::Prune(int min_length)
@@ -1244,6 +1247,9 @@ void ContigGraph::GetContigs(deque<Sequence> &contigs, deque<ContigInfo> &contig
 
 double ContigGraph::GetSimilarity(const Sequence &a, const Sequence &b)
 {
+    if (a.size() >= kMaxCheckSimilarity || b.size() > kMaxCheckSimilarity)
+        return 0;
+
     vector<vector<int> > table;
     table.resize(a.size() + 1);
     for (unsigned i = 0; i < table.size(); ++i)
@@ -1471,4 +1477,3 @@ double ContigGraph::FindSimilarPath(ContigGraphVertexAdaptor target, ContigGraph
     }
 }
 
-
